Package: MungeSumstats
Type: Package
Title: Standardise summary statistics from GWAS
Version: 1.20.0
Authors@R: 
    c(person(given = "Alan",
           family = "Murphy",
           role = c("aut","cre"),
           email = "alanmurph94@hotmail.com",
           comment = c(ORCID = "0000-0002-2487-8753")),
     person(given = "Brian",
           family = "Schilder",
           role = c("aut","ctb"),
           email = "brian_schilder@alumni.brown.edu",
           comment = c(ORCID = "0000-0001-5949-2191")),
    person(given = "Nathan",
           family = "Skene",
           role = c("aut"),
           email = "nathan.skene@gmail.com",
           comment = c(ORCID = "0000-0002-6807-3180"))) 
Description: 
  The *MungeSumstats* package is designed to facilitate the standardisation of 
  GWAS summary statistics. It reformats inputted summary statisitics to include 
  SNP, CHR, BP and can look up these values if any are missing. It also pefrorms 
  dozens of QC and filtering steps to ensure high data quality and
  minimise inter-study differences. 
URL: https://github.com/neurogenomics/MungeSumstats,
        https://al-murphy.github.io/MungeSumstats/
BugReports: https://github.com/neurogenomics/MungeSumstats/issues
License: Artistic-2.0
Depends: R(>= 4.1)
Imports: data.table, utils, R.utils, dplyr, stats, GenomicRanges,
        GenomeInfoDb, IRanges, ieugwasr(>= 1.0.1), BSgenome,
        Biostrings, stringr, VariantAnnotation, methods, parallel,
        rtracklayer(>= 1.59.1), RCurl
biocViews: SNP, WholeGenome, Genetics, ComparativeGenomics,
        GenomeWideAssociation, GenomicVariation, Preprocessing
RoxygenNote: 7.3.2
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Suggests: SNPlocs.Hsapiens.dbSNP144.GRCh37,
        SNPlocs.Hsapiens.dbSNP144.GRCh38,
        SNPlocs.Hsapiens.dbSNP155.GRCh37,
        SNPlocs.Hsapiens.dbSNP155.GRCh38,
        BSgenome.Hsapiens.1000genomes.hs37d5,
        BSgenome.Hsapiens.NCBI.GRCh38, BiocGenerics, S4Vectors,
        rmarkdown, markdown, knitr, testthat (>= 3.0.0), UpSetR,
        BiocStyle, covr, Rsamtools, MatrixGenerics, badger,
        BiocParallel, GenomicFiles
Config/testthat/edition: 3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/MungeSumstats
git_branch: RELEASE_3_23
git_last_commit: 63fc668
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:31:41 UTC; biocbuild
Author: Alan Murphy [aut, cre] (ORCID: <https://orcid.org/0000-0002-2487-8753>),
  Brian Schilder [aut, ctb] (ORCID:
    <https://orcid.org/0000-0001-5949-2191>),
  Nathan Skene [aut] (ORCID: <https://orcid.org/0000-0002-6807-3180>)
Maintainer: Alan Murphy <alanmurph94@hotmail.com>
